@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2017, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -137,8 +137,10 @@ char * opt_reverse;
 char * opt_samout;
 char * opt_search_exact;
 char * opt_shuffle;
+char * opt_sintax;
 char * opt_sortbylength;
 char * opt_sortbysize;
+char * opt_tabbedout;
 char * opt_udb2fasta;
 char * opt_udbinfo;
 char * opt_udbstats;
@@ -154,6 +156,7 @@ char * opt_userout;
 double * opt_ee_cutoffs_values;
 double opt_abskew;
 double opt_dn;
+double opt_fastq_maxdiffpct;
 double opt_fastq_maxee;
 double opt_fastq_maxee_rate;
 double opt_fastq_truncee;
@@ -172,6 +175,7 @@ double opt_minsizeratio;
 double opt_minsl;
 double opt_query_cov;
 double opt_sample_pct;
+double opt_sintax_cutoff;
 double opt_target_cov;
 double opt_unoise_alpha;
 double opt_weak_id;
@@ -657,6 +661,7 @@ void args_init(int argc, char **argv)
   opt_fastq_eestats = 0;
   opt_fastq_eestats2 = 0;
   opt_fastq_filter = 0;
+  opt_fastq_maxdiffpct = 100.0;
   opt_fastq_maxdiffs = 10;
   opt_fastq_maxee = DBL_MAX;
   opt_fastq_maxee_rate = DBL_MAX;
@@ -779,6 +784,8 @@ void args_init(int argc, char **argv)
   opt_self = 0;
   opt_selfid = 0;
   opt_shuffle = 0;
+  opt_sintax = 0;
+  opt_sintax_cutoff = 0.0;
   opt_sizein = 0;
   opt_sizeorder = 0;
   opt_sizeout = 0;
@@ -786,6 +793,7 @@ void args_init(int argc, char **argv)
   opt_sortbylength = 0;
   opt_sortbysize = 0;
   opt_strand = 1;
+  opt_tabbedout = 0;
   opt_target_cov = 0.0;
   opt_threads = 0;
   opt_top_hits_only = 0;
@@ -1012,6 +1020,10 @@ void args_init(int argc, char **argv)
     {"unoise_alpha",          required_argument, 0, 0 },
     {"uchime2_denovo",        required_argument, 0, 0 },
     {"uchime3_denovo",        required_argument, 0, 0 },
+    {"sintax",                required_argument, 0, 0 },
+    {"sintax_cutoff",         required_argument, 0, 0 },
+    {"tabbedout",             required_argument, 0, 0 },
+    {"fastq_maxdiffpct",      required_argument, 0, 0 },
     { 0, 0, 0, 0 }
   };
 
@@ -1833,7 +1845,7 @@ void args_init(int argc, char **argv)
         case 192:
           opt_unoise_alpha = args_getdouble(optarg);
           break;
-        
+
         case 193:
           opt_uchime2_denovo = optarg;
           break;
@@ -1842,6 +1854,22 @@ void args_init(int argc, char **argv)
           opt_uchime3_denovo = optarg;
           break;
 
+        case 195:
+          opt_sintax = optarg;
+          break;
+
+        case 196:
+          opt_sintax_cutoff = args_getdouble(optarg);
+          break;
+
+        case 197:
+          opt_tabbedout = optarg;
+          break;
+
+        case 198:
+          opt_fastq_maxdiffpct = args_getdouble(optarg);
+          break;
+
         default:
           fatal("Internal error in option parsing");
         }
@@ -1927,6 +1955,8 @@ void args_init(int argc, char **argv)
     commands++;
   if (opt_uchime3_denovo)
     commands++;
+  if (opt_sintax)
+    commands++;
 
 
   if (commands > 1)
@@ -2014,6 +2044,10 @@ void args_init(int argc, char **argv)
   if (opt_gzip_decompress && opt_bzip2_decompress)
     fatal("Specify either --gzip_decompress or --bzip2_decompress, not both");
 
+  if ((opt_sintax_cutoff < 0.0) || (opt_sintax_cutoff > 1.0))
+    fatal("The argument to sintax_cutoff must be in the range 0.0 to 1.0");
+
+
   /* TODO: check valid range of gap penalties */
 
   /* adapt/adjust parameters */
@@ -2057,7 +2091,7 @@ void args_init(int argc, char **argv)
       else
         opt_minsize = 0;
     }
-      
+
   /* set default opt_abskew depending on command */
   if (opt_abskew < 0.0)
     {
@@ -2073,7 +2107,7 @@ void args_init(int argc, char **argv)
     {
       if (opt_cluster_smallmem || opt_cluster_fast || opt_cluster_size ||
           opt_usearch_global || opt_derep_fulllength || opt_derep_prefix ||
-          opt_makeudb_usearch || opt_cluster_unoise)
+          opt_makeudb_usearch || opt_cluster_unoise || opt_sintax)
         opt_minseqlength = 32;
       else
         opt_minseqlength = 1;
@@ -2304,6 +2338,7 @@ void cmd_help()
               " Parameters\n"
               "  --fastq_allowmergestagger   Allow merging of staggered reads\n"
               "  --fastq_ascii INT           FASTQ input quality score ASCII base char (33)\n"
+              "  --fastq_maxdiffpct REAL     maximum percentage diff. bases in overlap (100.0)\n"
               "  --fastq_maxdiffs INT        maximum number of different bases in overlap (10)\n"
               "  --fastq_maxee REAL          maximum expected error value for merged sequence\n"
               "  --fastq_maxmergelen         maximum length of entire merged sequence\n"
@@ -2456,6 +2491,14 @@ void cmd_help()
               "  --sizeout                   update abundance information in output\n"
               "  --xsize                     strip abundance information in output\n"
               "\n"
+              "Taxonomic classification\n"
+              "  --sintax FILENAME           classify sequences in given FASTA/FASTQ file\n"
+              " Parameters\n"
+              "  --db FILENAME               taxonomic reference db in given FASTA or UDB file\n"
+              "  --sintax_cutoff REAL        confidence value cutoff level (0.0)\n"
+              " Output\n"
+              "  --tabbedout FILENAME        write results to given tab-delimited file\n"
+              "\n"
               "UDB files\n"
               "  --makeudb_usearch FILENAME  make UDB file from given FASTA file\n"
               "  --udb2fasta FILENAME        output FASTA file from given UDB file\n"
@@ -2841,6 +2884,8 @@ int main(int argc, char** argv)
       fprintf(fp_log, "Started  %s\n", time_string);
     }
 
+  random_init();
+
   show_header();
 
   dynlibs_open();
@@ -2906,6 +2951,8 @@ int main(int argc, char** argv)
     udb_info();
   else if (opt_udbstats)
     udb_stats();
+  else if (opt_sintax)
+    sintax();
   else
     cmd_none();
 
